@@ -13,10 +13,10 @@ import (
 	"sync"
 	"time"
 
-	"github.com/ginuerzh/gosocks4"
-	"github.com/ginuerzh/gosocks5"
+	"github.com/go-gost/gosocks4"
+	"github.com/go-gost/gosocks5"
 	"github.com/go-log/log"
-	smux "gopkg.in/xtaci/smux.v1"
+	smux "github.com/xtaci/smux"
 )
 
 const (
